open Cechannels
open Cestrings

(* ######################################### Module : fonctions sur les source_buffer  *)
(* fonctions de manipulation des GSourceView2.source_buffer et liaisons avec les fichiers *)
let extremites_tampon (tampon:GSourceView2.source_buffer) =
	let debut = tampon#start_iter and fin = tampon#end_iter in
	(debut, fin);;

let vider_tampon (tampon:GSourceView2.source_buffer) =
	let debut, fin = extremites_tampon tampon in
	tampon#delete ~start:debut ~stop:fin;;
	
let lire_tampon (tampon:GSourceView2.source_buffer) =
	let debut, fin = extremites_tampon tampon in
	tampon#get_text ~start:debut ~stop:fin ();;

let ecrire_tampon (tampon:GSourceView2.source_buffer) contenu =
	tampon#set_text contenu;;

let ajouter_tampon (tampon2:GSourceView2.source_buffer) reponse =	
	let iter_fin = tampon2#end_iter in
	tampon2#place_cursor iter_fin;
	tampon2#insert ~tag_names:["surligne"] reponse;;
	
let enregistrer_tampon (tampon : GSourceView2.source_buffer) nom_fichier =
	let txt = lire_tampon tampon in
	string_to_file nom_fichier txt;;
	
let remplir_tampon (tampon : GSourceView2.source_buffer) nom_fichier =
	let contenu = file_to_string nom_fichier in
	ecrire_tampon tampon contenu;;
	
let recuperer_commande (tampon : GSourceView2.source_buffer) =
	let deuxieme_iter x =
		match x with
		| None -> tampon#end_iter
		| Some a -> snd a
	in
	let premier_iter x =
		match x with
		| None -> tampon#start_iter
		| Some a -> snd a
	in
	let debut,fin = 
	if not (tampon#has_selection) then begin
     (* -- premier cas : pas de texte sélectionné *)
	  (* position du curseur clignotant *)
	  let curseur = tampon#get_iter_at_mark `INSERT in
	  (* déplacement du curseur en début de ligne *)
	  curseur#nocopy#set_line_offset(0);
	  (* recherches des doubles points-virgules avant et après le curseur *)
	  let couple_iter_debut = curseur#backward_search ";;" in
	  let couple_iter_fin = curseur#forward_search ";;" in
	  (* curseurs de debut de commande et de fin de commande *)
	  (premier_iter couple_iter_debut),(deuxieme_iter couple_iter_fin)
	  end
	else begin
	  (* -- deuxième cas : texte sélectionné *)
	  tampon#selection_bounds 
	  end
	in
	(* extraction de la commande *)
	let com_brute = tampon#get_text ~start:debut ~stop:fin () in
	trim com_brute, debut, fin;;

let appliquer_tag (tampon : GSourceView2.source_buffer) tag_name debut fin =
	tampon#apply_tag_by_name tag_name ~start:debut ~stop:fin;;
let appliquer_tag_partout (tampon : GSourceView2.source_buffer) tag_name =
	let debut, fin = extremites_tampon tampon in
	tampon#apply_tag_by_name tag_name ~start:debut ~stop:fin;;
let appliquer_tag_partout_par_tag (tampon : GSourceView2.source_buffer) tag =
	let debut, fin = extremites_tampon tampon in
	tampon#apply_tag tag ~start:debut ~stop:fin;;
let effacer_tag (tampon : GSourceView2.source_buffer) tag_name =
	let debut, fin = extremites_tampon tampon in
	tampon#remove_tag_by_name tag_name ~start:debut ~stop:fin;;


